@@ -9,6 +9,7 @@ from neurora.stuff import limtozero
 import math
 from scipy.stats import pearsonr
 from neurora.stuff import show_progressbar
+from neurora.decoding import tbyt_decoding_kfold
 
 np.seterr(divide='ignore', invalid='ignore')
 
@@ -171,7 +172,7 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
     return rdm
 
 
-' a function for calculating the RDM(s) based on EEG/MEG/fNIRS data '
+' a function for calculating the RDM(s) based on EEG/MEG/fNIRS & other EEG-like data '
 
 def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5, method="correlation", abs=False):
 
@@ -215,7 +216,7 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
     Returns
     -------
     RDM(s) : array
-        The EEG/MEG/fNIR RDM.
+        The EEG/MEG/fNIR/other EEG-like RDM.
         If sub_opt=0 & chl_opt=0 & time_opt=0, return only one RDM.
             The shape is [n_cons, n_cons].
         If sub_opt=0 & chl_opt=0 & time_opt=1, return int((n_ts-time_win)/time_step)+1 RDM.
@@ -281,7 +282,7 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
                     for k in range(ts):
 
                         # show the progressbar
-                        percent = (i*chls*ts+j*ts+k) / total * 100
+                        percent = (i * chls * ts + j * ts + k + 1) / total * 100
                         show_progressbar("Calculating", percent)
 
                         for l in range(cons):
@@ -335,7 +336,7 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
             for k in range(ts):
 
                 # show the progressbar
-                percent = (i * ts + j) / total * 100
+                percent = (i * ts + k + 1) / total * 100
                 show_progressbar("Calculating", percent)
 
                 for l in range(cons):
@@ -395,7 +396,7 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
             for j in range(chls):
 
                 # show the progressbar
-                percent = (i * chls + j) / total * 100
+                percent = (i * chls + j + 1) / total * 100
                 show_progressbar("Calculating", percent)
 
                 for k in range(cons):
@@ -492,6 +493,99 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
         return rdms
 
 
+' a function for calculating the RDM(s) using classification-based neural decoding based on EEG/MEG/fNIRS & other EEG-like data '
+
+def eegRDM_bydecoding(EEG_data, sub_opt=1, time_win=5, time_step=5, navg=5, time_opt="average", nfolds=5, nrepeats=2,
+                      normalization=False):
+
+    """
+    Calculate the Representational Dissimilarity Matrix(Matrices) - RDM(s) based on EEG-like data
+
+    Parameters
+    ----------
+    EEG_data : array
+        The EEG/MEG/fNIRS data.
+        The shape of EEGdata must be [n_cons, n_subs, n_trials, n_chls, n_ts].
+        n_cons, n_subs, n_trials, n_chls & n_ts represent the number of conidtions, the number of subjects, the number
+        of trials, the number of channels & the number of time-points, respectively.
+    sub_opt: int 0 or 1. Default is 1.
+        Return the subject-result or average-result.
+        If sub_opt=0, return the average result.
+        If sub_opt=1, return the results of each subject.
+    time_win : int. Default is 5.
+        Set a time-window for calculating the RDM for different time-points.
+        Only when time_opt=1, time_win works.
+        If time_win=5, that means each calculation process based on 5 time-points.
+    time_step : int. Default is 5.
+        The time step size for each time of calculating.
+        Only when time_opt=1, time_step works.
+    navg : int. Default is 5.
+        The number of trials used to average.
+    time_opt : string "average" or "features". Default is "average".
+        Average the time-points or regard the time points as features for classification
+        If time_opt="average", the time-points in a certain time-window will be averaged.
+        If time_opt="features", the time-points in a certain time-window will be used as features for classification.
+    nfolds : int. Default is 5.
+        The number of folds.
+        k should be at least 2.
+    nrepeats : int. Default is 2.
+        The times for iteration.
+    normalization : boolean True or False. Default is False.
+        Normalize the data or not.
+
+    Returns
+    -------
+    RDM(s) : array
+        The EEG/MEG/fNIR/other EEG-like RDM.
+        If sub_opt=0, return int((n_ts-time_win)/time_step)+1 RDMs.
+            The shape is [int((n_ts-time_win)/time_step)+1, n_cons, n_cons].
+        If sub_opt=1, return n_subs*int((n_ts-time_win)/time_step)+1 RDM.
+            The shape is [n_subs, int((n_ts-time_win)/time_step)+1, n_cons, n_cons].
+
+    Notes
+    -----
+    Sometimes, the numbers of trials under different conditions are not same. In NeuroRA, we recommend users to sample
+    randomly from the trials under each conditions to keep the numbers of trials under different conditions same, and
+    you can iterate multiple times.
+    """
+
+    if len(np.shape(EEG_data)) != 5:
+
+        print("The shape of input for eegRDM() function must be [n_cons, n_subs, n_trials, n_chls, n_ts].\n")
+
+        return "Invalid input!"
+
+    # get the number of conditions, subjects, trials, channels and time points
+    cons, subs, trials, chls, ts = np.shape(EEG_data)
+
+    ts = int((ts - time_win) / time_step) + 1
+
+    rdms = np.zeros([subs, ts, cons, cons])
+
+    for con1 in range(cons):
+        for con2 in range(cons):
+
+            if con1 != con2:
+
+                data = np.concatenate((EEG_data[con1], EEG_data[con2]), axis=1)
+                print(data.shape)
+                labels = np.zeros([subs, 2*trials])
+                labels[:, trials:] = 1
+                print(labels.shape)
+                rdms[:, :, con1, con2] = tbyt_decoding_kfold(data, labels, n=2, navg=navg, time_opt=time_opt,
+                                                             time_win=time_win, time_step=time_step, nfolds=nfolds,
+                                                             nrepeats=nrepeats, normalization=normalization,
+                                                             smooth=True)
+
+    if sub_opt == 0:
+
+        return np.average(rdms, axis=0)
+
+    else:
+
+        return rdms
+
+
 ' a function for calculating the RDMs based on fMRI data (searchlight) '
 
 def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="correlation", abs=False):
@@ -596,7 +690,7 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
                 for z in range(n_z):
 
                     # show the progressbar
-                    percent = (sub * n_x * n_y * n_z + x * n_y * n_z + y * n_z + z) / total * 100
+                    percent = (sub * n_x * n_y * n_z + x * n_y * n_z + y * n_z + z + 1) / total * 100
                     show_progressbar("Calculating", percent)
 
                     for i in range(cons):
@@ -638,7 +732,7 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
         return subrdms
 
 
-' a function for calculating the RDM based on fMRI data of a ROI '
+' a function for calculating the RDM based on fMRI data of an ROI '
 
 def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False):
 
