@@ -8,11 +8,12 @@ import numpy as np
 import matplotlib.pyplot as plt
 from scipy.interpolate import interp1d
 from scipy import signal
-from scipy.stats import ttest_1samp
+from scipy.stats import ttest_1samp, ttest_rel
 from nilearn import plotting, datasets, surface
 import nibabel as nib
-from neurora.stuff import get_affine, correct_by_threshold, get_bg_ch2, get_bg_ch2bet, \
-    clusterbased_permutation_1d_1samp_1sided, clusterbased_permutation_2d_1samp_1sided
+from neurora.stuff import get_affine, get_bg_ch2, get_bg_ch2bet, correct_by_threshold, \
+    clusterbased_permutation_1d_1samp_1sided, clusterbased_permutation_2d_1samp_1sided, \
+    clusterbased_permutation_1d_1samp_2sided, clusterbased_permutation_2d_2sided
 from decimal import Decimal
 
 
@@ -341,8 +342,9 @@ def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1]):
 
 ' a function for plotting the time-by-time Similarities with statistical results'
 
-def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True, p=0.05, cbpt=True, color='r',
-                           lim=[-0.1, 0.8], figsize=[6.4, 3.6], x0=0, fontsize=16):
+def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval=0.01, smooth=True, p=0.05, cbpt=True,
+                           stats_time=[0, 1], color='r', xlim=[0, 1], ylim=[-0.1, 0.8], figsize=[6.4, 3.6], x0=0,
+                           fontsize=16, avgshow=False):
 
     """
     Plot the time-by-time Similarities with statistical results
@@ -357,22 +359,32 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True,
         The start time.
     end_time : int or float. Default is 1.
         The end time.
+    time_interval : float. Default is 0.01.
+        The time interval between two time samples.
     smooth : bool True or False. Default is True.
         Smooth the results or not.
+    chance : float. Default is 0.5.
+        The chance level.
     p : float. Default is 0.05.
         The threshold of p-values.
     cbpt : bool True or False. Default is True.
         Conduct cluster-based permutation test or not.
+    stats_time : array or list [stats_time1, stats_time2]. Default os [0, 1].
+        Time period for statistical analysis.
     color : matplotlib color or None. Default is 'r'.
         The color for the curve.
-    lim : array or list [min, max]. Default is [-0.1, 0.8].
-        The corrs view lims.
+    xlim : array or list [xmin, xmax]. Default is [0, 1].
+        The x-axis (time) view lims.
+    ylim : array or list [ymin, ymax]. Default is [0.4, 0.8].
+        The y-axis (decoding accuracy) view lims.
     figsize : array or list, [size_X, size_Y]. Default is [6.4, 3.6].
         The size of the figure.
     x0 : float. Default is 0.
         The Y-axis is at x=x0.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
+    avgshow : boolen True or False. Default is False.
+        Show the averaging decoding accuracies or not.
     """
 
     if len(np.shape(similarities)) < 2 or len(np.shape(similarities)) > 3:
@@ -381,16 +393,28 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True,
 
     n = len(np.shape(similarities))
 
-    minlim = lim[0]
-    maxlim = lim[1]
+    yminlim = ylim[0]
+    ymaxlim = ylim[1]
 
     if n == 3:
         similarities = similarities[:, :, 0]
 
-    nsubs = np.shape(similarities)[0]
-    nts = np.shape(similarities)[1]
+    nsubs, nts = np.shape(similarities)
+    tstep = float(Decimal((end_time - start_time) / nts).quantize(Decimal(str(time_interval))))
 
-    tstep = float((end_time-start_time)/nts)
+    if tstep != time_interval:
+        return "Invalid input!"
+
+    delta1 = (stats_time[0] - start_time) / tstep - int((stats_time[0] - start_time) / tstep)
+    delta2 = (stats_time[1] - start_time) / tstep - int((stats_time[1] - start_time) / tstep)
+    if delta1 == 0:
+        stats_time1 = int((stats_time[0] - start_time) / tstep)
+    else:
+        stats_time1 = int((stats_time[0] - start_time) / tstep) + 1
+    if delta2 == 0:
+        stats_time2 = int((stats_time[1] - start_time) / tstep)
+    else:
+        stats_time2 = int((stats_time[1] - start_time) / tstep) + 1
 
     if smooth is True:
         for sub in range(nsubs):
@@ -410,7 +434,9 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True,
         err[t] = np.std(similarities[:, t], ddof=1)/np.sqrt(nsubs)
 
     if cbpt == True:
-        ps = clusterbased_permutation_1d_1samp_1sided(similarities, level=0, p_threshold=p)
+        ps_stats = clusterbased_permutation_1d_1samp_1sided(similarities, level=0, p_threshold=p)
+        ps = np.zeros([nts])
+        ps[stats_time1:stats_time2] = ps_stats
     else:
         ps = np.zeros([nts])
         for t in range(nts):
@@ -422,7 +448,7 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True,
 
     for t in range(nts):
         if ps[t] == 1:
-            plt.plot(t*tstep+start_time, (maxlim-minlim)*0.9+minlim, 's', color=color, alpha=1)
+            plt.plot(t*tstep+start_time, (ymaxlim-yminlim)*0.9+yminlim, 's', color=color, alpha=1)
             xi = [t*tstep+start_time, t*tstep+tstep+start_time]
             ymin = [0]
             ymax = [avg[t]-err[t]]
@@ -438,11 +464,12 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True,
     ax.spines["left"].set_position(("data", x0))
     ax.spines["bottom"].set_linewidth(3)
     ax.spines['bottom'].set_position(('data', 0))
-
     x = np.arange(start_time+0.5*tstep, end_time+0.5*tstep, tstep)
+    if avgshow is True:
+        plt.plot(x, avg, color=color, alpha=0.9)
     plt.fill_between(x, avg + err, avg - err, facecolor=color, alpha=0.8)
-    plt.ylim(minlim, maxlim)
-    plt.xlim(start_time, end_time)
+    plt.ylim(yminlim, ymaxlim)
+    plt.xlim(xlim[0], xlim[1])
     plt.tick_params(labelsize=12)
     plt.xlabel("Time (s)", fontsize=fontsize)
     plt.ylabel("Representational Similarity", fontsize=fontsize)
@@ -572,6 +599,162 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
     plt.show()
 
 
+' a function for plotting the differences of time-by-time decoding accuracies between two conditions '
+
+def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_interval=0.01, chance=0.5, p=0.05, cbpt=True,
+                                stats_time=[0, 1], color1='r', color2='b', xlim=[0, 1], ylim=[0.4, 0.8],
+                                figsize=[6.4, 3.6], x0=0, fontsize=16, avgshow=False):
+
+    """
+    Plot the differences of time-by-time decoding accuracies between two conditions
+
+    Parameters
+    ----------
+    acc1 : array
+        The decoding accuracies under condition1.
+        The size of acc1 should be [n_subs, n_ts]. n_subs, n_ts represent the number of subjects and number of
+        time-points.
+    acc2 : array
+        The decoding accuracies under condition2.
+        The size of acc2 should be [n_subs, n_ts]. n_subs, n_ts represent the number of subjects and number of
+        time-points.
+    start_time : int or float. Default is 0.
+        The start time.
+    end_time : int or float. Default is 1.
+        The end time.
+    time_interval : float. Default is 0.01.
+        The time interval between two time samples.
+    chance : float. Default is 0.5.
+        The chance level.
+    p : float. Default is 0.05.
+        The threshold of p-values.
+    cbpt : bool True or False. Default is True.
+        Conduct cluster-based permutation test or not.
+    stats_time : array or list [stats_time1, stats_time2]. Default os [0, 1].
+        Time period for statistical analysis.
+    color1 : matplotlib color or None. Default is 'r'.
+        The color for the curve under condition1.
+    color2 : matplotlib color or None. Default is 'r'.
+        The color for the curve under condition2.
+    xlim : array or list [xmin, xmax]. Default is [0, 1].
+        The x-axis (time) view lims.
+    ylim : array or list [ymin, ymax]. Default is [0.4, 0.8].
+        The y-axis (decoding accuracy) view lims.
+    figsize : array or list, [size_X, size_Y]. Default is [6.4, 3.6].
+        The size of the figure.
+    x0 : float. Default is 0.
+        The Y-axis is at x=x0.
+    fontsize : int or float. Default is 16.
+        The fontsize of the labels.
+    avgshow : boolen True or False. Default is False.
+        Show the averaging decoding accuracies or not.
+    """
+
+    if len(np.shape(acc1)) != 2 or len(np.shape(acc2)) != 2:
+
+        return "Invalid input!"
+
+    nsubs, nts = np.shape(acc1)
+    tstep = float(Decimal((end_time - start_time) / nts).quantize(Decimal(str(time_interval))))
+
+    if tstep != time_interval:
+
+        return "Invalid input!"
+
+    delta1 = (stats_time[0] - start_time) / tstep - int((stats_time[0] - start_time) / tstep)
+    delta2 = (stats_time[1] - start_time) / tstep - int((stats_time[1] - start_time) / tstep)
+    if delta1 == 0:
+        stats_time1 = int((stats_time[0] - start_time) / tstep)
+    else:
+        stats_time1 = int((stats_time[0] - start_time) / tstep) + 1
+    if delta2 == 0:
+        stats_time2 = int((stats_time[1] - start_time) / tstep)
+    else:
+        stats_time2 = int((stats_time[1] - start_time) / tstep) + 1
+
+    yminlim = ylim[0]
+    ymaxlim = ylim[1]
+
+    avg1 = np.average(acc1, axis=0)
+    err1 = np.zeros([nts])
+    for t in range(nts):
+        err1[t] = np.std(acc1[:, t], ddof=1) / np.sqrt(nsubs)
+
+    avg2 = np.average(acc2, axis=0)
+    err2 = np.zeros([nts])
+    for t in range(nts):
+        err2[t] = np.std(acc2[:, t], ddof=1) / np.sqrt(nsubs)
+
+    if cbpt == True:
+
+        ps_stats = clusterbased_permutation_1d_1samp_2sided(acc1[:, stats_time1:stats_time2]-
+                                                            acc2[:, stats_time1:stats_time2], level=0, p_threshold=p,
+                                                            iter=1000)
+        ps = np.zeros([nts])
+        ps[stats_time1:stats_time2] = ps_stats
+
+    else:
+        ps1 = np.zeros([nts])
+        ps2 = np.zeros([nts])
+        ps = np.zeros([nts])
+        for t in range(nts):
+            if t >= stats_time1 and t< stats_time2:
+                ps1[t] = ttest_1samp(acc1[:, t], chance, alternative="greater")[1]
+                ps2[t] = ttest_1samp(acc2[:, t], chance, alternative="greater")[1]
+                if ps1[t] < p:
+                    ps1[t] = 1
+                else:
+                    ps1[t] = 0
+                if ps2[t] < p:
+                    ps2[t] = 1
+                else:
+                    ps2[t] = 0
+                if ttest_rel(acc1[:, t], acc1[:, t], alternative="greater")[1] < p:
+                    ps[t] = 1
+                elif ttest_rel(acc1[:, t], acc1[:, t], alternative="less")[1] < p:
+                    ps[t] = -1
+                else:
+                    ps[t] = 0
+
+    for t in range(nts):
+        if ps1[t] == 1:
+            plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.9+yminlim, 's', color=color1, alpha=0.8)
+        if ps2[t] == 1:
+            plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.9+yminlim, 's', color=color2, alpha=0.8)
+        if ps[t] == 1:
+            xi = [t*tstep+start_time, t*tstep+tstep+start_time]
+            ymin = [avg2[t] + err2[t]]
+            ymax = [avg1[t] - err1[t]]
+            plt.fill_between(xi, ymax, ymin, facecolor="grey", alpha=0.2)
+        if ps[t] == -1:
+            xi = [t*tstep+start_time, t*tstep+tstep+start_time]
+            ymin = [avg1[t] + err1[t]]
+            ymax = [avg2[t] - err2[t]]
+            plt.fill_between(xi, ymax, ymin, facecolor="grey", alpha=0.2)
+
+    fig = plt.gcf()
+    fig.set_size_inches(figsize[0], figsize[1])
+    ax = plt.gca()
+    ax.spines["top"].set_visible(False)
+    ax.spines["right"].set_visible(False)
+    ax.spines["left"].set_linewidth(3)
+    ax.spines["left"].set_position(("data", x0))
+    ax.spines["bottom"].set_linewidth(3)
+    ax.spines["bottom"].set_position(("data", chance))
+    x = np.arange(start_time+0.5*tstep, end_time+0.5*tstep, tstep)
+    if avgshow is True:
+        plt.plot(x, avg1, color=color1, alpha=0.9)
+        plt.plot(x, avg2, color=color2, alpha=0.9)
+    plt.fill_between(x, avg1+err1, avg1-err1, facecolor=color1, alpha=0.8)
+    plt.fill_between(x, avg2+err2, avg2-err2, facecolor=color2, alpha=0.8)
+    plt.ylim(yminlim, ymaxlim)
+    plt.xlim(xlim[0], xlim[1])
+    plt.tick_params(labelsize=12)
+    plt.xlabel("Time (s)", fontsize=fontsize)
+    plt.ylabel("Decoding Accuracy", fontsize=fontsize)
+    plt.show()
+
+
 ' a function for plotting cross-temporal decoding accuracies '
 
 def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_timey=1, time_intervalx=0.01,
@@ -706,6 +889,147 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
     plt.show()
 
 
+' a function for plotting the differences of cross-temporal decoding accuracies between two conditions '
+
+def plot_ct_diff_decoding_acc(acc1, acc2, start_timex=0, end_timex=1, start_timey=0, end_timey=1, time_intervalx=0.01,
+                         time_intervaly=0.01, p=0.05, cbpt=True, stats_timex=[0, 1], stats_timey=[0, 1], xlim=[0, 1],
+                         ylim=[0, 1], clim=[0.4, 0.8], figsize=[6.4, 4.8], cmap="viridis", fontsize=16):
+
+    """
+    Plot the differences of cross-temporal decoding accuracies between two conditions
+
+    Parameters
+    ----------
+    acc1 : array
+        The decoding accuracies under condition1.
+        The size of acc should be [n_subs, n_tsx, n_tsy]. n_subs, n_tsx and n_tsy represent the number of subjects,
+        the number of training time-points and the number of test time-points.
+    acc2 : array
+        The decoding accuracies under condition2.
+        The size of acc should be [n_subs, n_tsx, n_tsy]. n_subs, n_tsx and n_tsy represent the number of subjects,
+        the number of training time-points and the number of test time-points.
+    start_timex : int or float. Default is 0.
+        The training start time.
+    end_timex : int or float. Default is 1.
+        The training end time.
+    start_timey : int or float. Default is 0.
+        The test start time.
+    end_timey : int or float. Default is 1.
+        The test end time.
+    time_intervalx : float. Default is 0.01.
+        The training time interval between two time samples.
+    time_intervaly : float. Default is 0.01.
+        The test time interval between two time samples.
+    chance : float. Default is 0.5.
+        The chance level.
+    p : float. Default is 0.05.
+        The threshold of p-values.
+    cbpt : bool True or False. Default is True.
+        Conduct cluster-based permutation test or not.
+    stats_timex : array or list [stats_timex1, stats_timex2]. Default os [0, 1].
+        Trainning time period for statistical analysis.
+    stats_timey : array or list [stats_timey1, stats_timey2]. Default os [0, 1].
+        Test time period for statistical analysis.
+    xlim : array or list [xmin, xmax]. Default is [0, 1].
+        The x-axis (training time) view lims.
+    ylim : array or list [ymin, ymax]. Default is [0, 1].
+        The y-axis (test time) view lims.
+    clim : array or list [cmin, cmax]. Default is [0.4, 0.8].
+        The color-bar (decoding accuracy) view lims.
+    figsize : array or list, [size_X, size_Y]. Default is [6.4, 3.6].
+        The size of the figure.
+    cmap : matplotlib colormap or None. Default is None.
+        The colormap for the figure.
+    fontsize : int or float. Default is 16.
+        The fontsize of the labels.
+    """
+
+    acc = acc1 - acc2
+    nsubs, nx, ny = np.shape(acc)
+    cminlim = clim[0]
+    cmaxlim = clim[1]
+
+    tstepx = float(Decimal((end_timex - start_timex) / nx).quantize(Decimal(str(time_intervalx))))
+    tstepy = float(Decimal((end_timey - start_timey) / ny).quantize(Decimal(str(time_intervaly))))
+    print(tstepx, tstepy)
+    print(time_intervalx, time_intervaly)
+
+    if tstepx != time_intervalx or tstepy != time_intervaly:
+        return "Invalid input!"
+
+    deltax1 = (stats_timex[0] - start_timex) / tstepx - int((stats_timex[0] - start_timex) / tstepx)
+    deltax2 = (stats_timex[1] - start_timex) / tstepx - int((stats_timex[1] - start_timex) / tstepx)
+    if deltax1 == 0:
+        stats_timex1 = int((stats_timex[0] - start_timex) / tstepx)
+    else:
+        stats_timex1 = int((stats_timex[0] - start_timex) / tstepx) + 1
+    if deltax2 == 0:
+        stats_timex2 = int((stats_timex[1] - start_timex) / tstepx)
+    else:
+        stats_timex2 = int((stats_timex[1] - start_timex) / tstepx) + 1
+
+    deltay1 = (stats_timey[0] - start_timey) / tstepy - int((stats_timey[0] - start_timey) / tstepy)
+    deltay2 = (stats_timey[1] - start_timey) / tstepy - int((stats_timey[1] - start_timey) / tstepy)
+    if deltay1 == 0:
+        stats_timey1 = int((stats_timey[0] - start_timey) / tstepy)
+    else:
+        stats_timey1 = int((stats_timey[0] - start_timey) / tstepy) + 1
+    if deltay2 == 0:
+        stats_timey2 = int((stats_timey[1] - start_timey) / tstepy)
+    else:
+        stats_timey2 = int((stats_timey[1] - start_timey) / tstepy) + 1
+
+    if cbpt is True:
+
+        ps_stats = clusterbased_permutation_2d_2sided(acc1[:, stats_timex1:stats_timex2, stats_timey1:stats_timey2],
+                                                      acc2[:, stats_timex1:stats_timex2, stats_timey1:stats_timey2],
+                                                      p_threshold=p, iter=1000)
+        ps = np.zeros([nx, ny])
+        ps[stats_timex1:stats_timex2, stats_timey1:stats_timey2] = ps_stats
+
+    else:
+        ps = np.zeros([nx, ny])
+        for t1 in range(nx):
+            for t2 in range(ny):
+                if t1 >= stats_timex1 and t1 < stats_timex2 and t2 >= stats_timey1 and t2 < stats_timey2:
+                    if ttest_1samp(acc[:, t1, t2], 0, alternative="greater")[1] < p:
+                        ps[t1, t2] = 1
+                    elif ttest_1samp(acc[:, t1, t2], 0, alternative="less")[1] < p:
+                        ps[t1, t2] = -1
+                    else:
+                        ps[t1, t2] = 0
+
+    newps = np.zeros([nx + 2, ny + 2])
+    newps[1:nx + 1, 1:ny + 1] = ps
+    x = np.linspace(start_timex - 0.5 * tstepx, end_timex + 0.5 * tstepx, nx + 2)
+    y = np.linspace(start_timey - 0.5 * tstepy, end_timey + 0.5 * tstepy, ny + 2)
+    X, Y = np.meshgrid(x, y)
+    plt.contour(X, Y, np.transpose(newps, (1, 0)), (-0.5, 0.5), colors="silver", alpha=0.9, linewidths=3,
+                linestyles="dashed")
+
+    fig = plt.gcf()
+    fig.set_size_inches(figsize[0], figsize[1])
+    ax = plt.gca()
+    ax.spines["top"].set_visible(False)
+    ax.spines["right"].set_visible(False)
+    ax.spines["left"].set_linewidth(2)
+    ax.spines["bottom"].set_linewidth(2)
+    avg = np.average(acc, axis=0)
+    avg = np.transpose(avg, (1, 0))
+    plt.imshow(avg, extent=(start_timex, end_timex, start_timey, end_timey), cmap=cmap, origin="lower",
+               clim=(cminlim, cmaxlim))
+    cb = plt.colorbar()
+    cb.ax.tick_params(labelsize=12)
+    font = {'size': 15}
+    cb.set_label("Differences of Decoding Accuracies", fontdict=font)
+    plt.xlim(xlim[0], xlim[1])
+    plt.ylim(ylim[0], ylim[1])
+    plt.tick_params(labelsize=12)
+    plt.xlabel("Training Time (s)", fontsize=fontsize)
+    plt.ylabel("Test Time (s)", fontsize=fontsize)
+    plt.show()
+
+
 ' a function for plotting the hotmap of correlations coefficients for channels/regions by time sequence '
 
 def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smooth=False, figsize=None, cmap=None):
@@ -853,7 +1177,8 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
 
 ' a function for plotting the hotmap of correlations coefficients for channels/regions by time sequence with the significant outline '
 
-def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], p_threshold=0.05, time_threshold=5, smooth=False, figsize=None, cmap=None):
+def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], p_threshold=0.05,
+                            time_threshold=5, smooth=False, figsize=None, cmap=None):
 
     """
     plot the hotmap of correlation coefficients for channels/regions by time sequence with the significant outline
@@ -1056,7 +1381,8 @@ def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], li
 
 ' a function for plotting the hotmap of neural pattern similarities for channels/regions by time sequence '
 
-def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], abs=False, smooth=False, figsize=None, cmap=None):
+def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], abs=False, smooth=False, figsize=None,
+                    cmap=None):
 
     """
     plot the hotmap of neural pattern similarities for channels/regions by time sequence
@@ -1157,7 +1483,7 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
     if cmap == None:
         plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower')
     else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
 
     fig = plt.gcf()
     size = fig.get_size_inches()
@@ -1195,7 +1521,8 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
 
 ' a function for plotting the hotmap of statistical results for channels/regions by time sequence '
 
-def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], smooth=False, figsize=None, cmap=None, outline=False, p_threshold=0.05, time_threshold=5):
+def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], smooth=False, figsize=None, cmap=None,
+                      outline=False, p_threshold=0.05, time_threshold=5):
 
     """
     plot the hotmap of statistical results for channels/regions by time sequence
